#!/bin/bash

# This script is to be called in Jenkin's build step

# 1) determine the required environment
# 2) Setup required environment
# 3) Build binaries
# 4)

# Make sure that we abort with an error if any single call fails
# That's especially important for the make calls
set -e

##### Update to requested revision
if [ -d .hg ]; then
  hg pull -r$USE_REV
  if [ "$USE_REV" == "tip" ]; then hg up -C default; else hg up -C -r $USE_REV; fi
  echo "Building revision: $USE_REV"
fi
if [ -d .git ]; then
  if [ "$USE_REV" == "tip" ]; then USE_REV=origin/master; fi
  git reset --hard $USE_REV
fi

##### Create project property file
if [ -f .devzone/build/type ]; then
  PROJECT_TYPE=`cat .devzone/build/type | head -n1`
else
  echo "No project type defined in .devzone/build/type."
  PROJECT_TYPE=default
fi
echo "Using build rules for project type $PROJECT_TYPE."
echo "PROJECT_TYPE=$PROJECT_TYPE" >> environment.tmp.log

if [ -f .devzone/build/$BUILD_TYPE/cache ]; then
  if [ -d .hg ]; then
    hg purge --all "listfile:.devzone/build/$BUILD_TYPE/cache"
  fi
  # TODO implement similar mechanism for git projects
fi


##### Actually build the project
case $PROJECT_TYPE in
  custom)
    ./.devzone/build/jenkins_build.sh
    ;;

  bash.nml) ;&
  bash)
    ##### Legacy for Old DevZone
    ./make.sh
    ;;

  nml-sub)
    ##### Nothing special currently for nml-stlye sub-projects
    ;&

  nml)
    ##### nml-style projects. NML version matters.
    nmlc --version
    ;&

  *)
    ##### nml, nfo, ...
    make NML=~/bin/repos/nmltest/nmlc
    make bundle_zip NML=~/bin/repos/nmltest/nmlc
    make bundle_src NML=~/bin/repos/nmltest/nmlc
    [ -f *source.tar ] && xz *source.tar
    ;;
esac

##### Generate checksums
for i in *.zip *.xz; do [ -e "$i" ] && md5sum $i > $i.md5; done || true

##### Generate build info
echo "Build date: `date --rfc-3339='seconds'`" > release.txt
echo "Build name: $BUILD_DISPLAY_NAME" >> release.txt
echo "Build logs: $BUILD_URL" >> release.txt
echo "Revision (requested / real): $USE_REV / `hg id -n`:`hg id`" >> release.txt
echo "NML: `nmlc --version`" >> release.txt
echo "grfcodec: `grfcodec -v`" >> release.txt
